@@ -33,14 +33,15 @@ class EntityServerConnector:
         GET = 'get'
         DELETE = 'delete'
 
-    @dataclass(kw_only=True)
-    class Config(AbmServiceConnector.Config):
-        server_name: str
+    Config = AbmServiceConnector.Config
 
-    Context = AbmServiceConnector.Context
+    @dataclass
+    class Context(AbmServiceConnector.Context):
+        project_name: str
 
     def __init__(self, config: Config, context: Context) -> None:
         self.config = config
+        self.context = context
         self._connector = AbmServiceConnector(config, context)
 
     async def get_one(self,
@@ -115,4 +116,4 @@ class EntityServerConnector:
         )
 
     def _construct_headers(self) -> dict[str, str]:
-        return {'server_name': self.config.server_name}
+        return {'server_name': self.context.project_name}
